#! /usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2020, NVIDIA CORPORATION. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import os
import sys

NSYS_CLI_DIR = os.path.join(
    os.path.dirname(os.path.realpath(__file__)),
    "nsy_cli_dist"
)


NSYS_BINARY = os.path.join(NSYS_CLI_DIR, "target-linux-x64/nsys")


CUSTOM_LD_LIBRARY_PATH = os.getenv('LD_LIBRARY_PATH', None)
CUSTOM_LD_LIBRARY_PATH = "{}:{}:{}".format(
    CUSTOM_LD_LIBRARY_PATH + ":" if CUSTOM_LD_LIBRARY_PATH is not None else "",
    "{}/host-linux-x64".format(NSYS_CLI_DIR),
    "{}/target-linux-x64".format(NSYS_CLI_DIR),
)


CUSTOM_PATH = "{}:{}".format(
    os.getenv('PATH', ""),
    "{}/target-linux-x64".format(NSYS_CLI_DIR)
)


def launch_command(binary, args, env):
    os.execve(binary, args, env)


def main():
    custom_env = os.environ.copy()
    custom_env["LD_LIBRARY_PATH"] = CUSTOM_LD_LIBRARY_PATH
    custom_env["PATH"] = CUSTOM_PATH
    launch_command(NSYS_BINARY, sys.argv, env=custom_env)


if __name__ == "__main__":
    sys.exit(main())
